@@ -15,25 +15,23 @@ use Symfony\Component\Validator\ConstraintViolationListInterface;
 
 /**
  * @author Tobias Nyholm <tobias.nyholm@gmail.com>
- *
- * @experimental in 4.3
  */
 class ValidationFailedException extends RuntimeException
 {
-    private $violations;
-    private $violatingMessage;
+    private ConstraintViolationListInterface $violations;
+    private object $violatingMessage;
 
-    /**
-     * @param object $violatingMessage
-     */
-    public function __construct($violatingMessage, ConstraintViolationListInterface $violations)
+    public function __construct(object $violatingMessage, ConstraintViolationListInterface $violations)
     {
         $this->violatingMessage = $violatingMessage;
         $this->violations = $violations;
 
-        parent::__construct(sprintf('Message of type "%s" failed validation.', \get_class($this->violatingMessage)));
+        parent::__construct(sprintf('Message of type "%s" failed validation.', $this->violatingMessage::class));
     }
 
+    /**
+     * @return object
+     */
     public function getViolatingMessage()
     {
         return $this->violatingMessage;
